<?php

declare(strict_types = 1);

namespace Drupal\solution\EventSubscriber;

use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\joinup_group\Event\GroupMenuLinksEvent;
use Drupal\solution\Entity\SolutionInterface;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Listens to group events.
 */
class SolutionGroupMenuLinksSubscriber implements EventSubscriberInterface {

  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    return [
      GroupMenuLinksEvent::class => 'addLinks',
    ];
  }

  /**
   * Listens to GroupMenuLinksEvent::ADD_LINKS event.
   *
   * @param \Drupal\joinup_group\Event\GroupMenuLinksEvent $event
   *   The event object.
   */
  public function addLinks(GroupMenuLinksEvent $event): void {
    $solution = $event->getGroup();
    if ($solution instanceof SolutionInterface) {
      $url = $solution->getCollection()->toUrl('glossary')->mergeOptions([
        'attributes' => [
          'class' => [
            'group-menu-link-external',
          ],
        ],
      ]);
      // Glossary menu link in solution is optional.
      $event->addMenuLink($url, 'Glossary', -7, ['enabled' => FALSE]);
    }
  }

}
